@@ -21,7 +21,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include "rpc-systemui.h"
+
 #include "xml-common.h"
 #include "debug.h"
 #include "queue.h"
@@ -472,7 +472,7 @@ static xmlNode *_alarmd_queue_to_xml(AlarmdObject *object)
 	guint n_properties = 0;
 	guint i;
 
-	xmlNode *node = xmlNewNode(NULL, "queue");
+	xmlNode *node = xmlNewNode(NULL, (xmlChar *) "queue");
 	ENTER_FUNC;
 
 	properties = alarmd_object_get_properties(object, &n_properties);
@@ -531,7 +531,7 @@ static xmlNode *_alarmd_queue_to_xml(AlarmdObject *object)
 			g_warning("Unsupported type: %s", g_type_name(G_VALUE_TYPE(&properties[i].value)));
 			break;
 		}
-		added_node = xmlNewChild(node, NULL, "parameter", temp);
+		added_node = xmlNewChild(node, NULL, (xmlChar *) "parameter", (xmlChar *) temp);
 		if (temp) {
 			g_free(temp);
 			temp = NULL;
@@ -543,8 +543,8 @@ static xmlNode *_alarmd_queue_to_xml(AlarmdObject *object)
 			if (G_VALUE_TYPE(&properties[i].value) == type_gtypes[j])
 				break;
 		}
-		xmlNewProp(added_node, "name", properties[i].name);
-		xmlNewProp(added_node, "type", type_names[j]);
+		xmlNewProp(added_node, (xmlChar *) "name", (xmlChar *) properties[i].name);
+		xmlNewProp(added_node, (xmlChar *) "type", (xmlChar *) type_names[j]);
 	}
 
 	alarmd_gparameterv_free(properties, n_properties);
